@@ -4,13 +4,29 @@ from .agent_binary_request import (
     AgentBinaryTransform,
     ReservationID,
 )
+from .dropper_execution_mode import DropperExecutionMode
 from .exploiter_result import ExploiterResult
 from .fingerprint_data import FingerprintData
 from .i_agent_binary_repository import IAgentBinaryRepository, RetrievalError
+from .i_agent_command_builder_factory import IAgentCommandBuilderFactory
+from .i_agent_event_publishler import IAgentEventPublisher
 from .i_agent_otp_provider import IAgentOTPProvider
 from .i_http_agent_binary_server_registrar import IHTTPAgentBinaryServerRegistrar
+from .i_linux_agent_command_builder import (
+    ILinuxAgentCommandBuilder,
+    LinuxDownloadMethod,
+    LinuxDownloadOptions,
+    LinuxRunOptions,
+)
 from .i_propagation_credentials_repository import IPropagationCredentialsRepository
 from .i_tcp_port_selector import ITCPPortSelector
+from .i_windows_agent_command_builder import (
+    IWindowsAgentCommandBuilder,
+    WindowsDownloadMethod,
+    WindowsDownloadOptions,
+    WindowsRunOptions,
+    WindowsShell,
+)
 from .local_machine_info import LocalMachineInfo
 from .payload_result import PayloadResult
 from .ping_scan_data import PingScanData
